@@ -1,8 +1,11 @@
-package String::Nudge;
-$String::Nudge::VERSION = '0.0101';
+use 5.10.1;
 use strict;
 use warnings;
-use 5.010000;
+
+package String::Nudge;
+
+our $VERSION = '0.1001'; # VERSION
+# ABSTRACT: Indents all lines in a multi-line string
 
 use Sub::Exporter::Progressive -setup => {
     exports => [qw/nudge/],
@@ -44,11 +47,17 @@ sub nudge ($;$) {
 
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-String::Nudge - Nudges all lines in a multi-line string
+String::Nudge - Indents all lines in a multi-line string
+
+=head1 VERSION
+
+Version 0.1001, released 2015-01-17.
 
 =head1 SYNOPSIS
 
@@ -69,7 +78,6 @@ String::Nudge - Nudges all lines in a multi-line string
     };
     }
 
-
 =head1 DESCRIPTION
 
 String::Nudge provides C<nudge>, a simple function that indents all lines in a multi line string.
@@ -90,7 +98,11 @@ If C<$number_of_spaces> is not given (or isn't an integer >= 0) its default valu
 
 Every line in C<$string> is indented by C<$number_of_spaces>. Lines only consisting of white space is trimmed (but not removed).
 
-C<nudge> works nicely together with L<qi|Syntax::Feature::Qi>:
+=head2 MORE EXAMPLES
+
+=head3 Usage with L<qi|Syntax::Feature::Qi>
+
+L<Syntax::Feature::Qi> adds C<qi> and C<qqi> that removes the same amount of leading whitespace as the first (significant) line has from all lines in a string:
 
     # these three packages are equivalent:
     package Example::Nudge {
@@ -130,29 +142,90 @@ C<nudge> works nicely together with L<qi|Syntax::Feature::Qi>:
         }
     }
 
+=head3 Usage with L<qs|Syntax::Feature::Qs>
+
+L<Syntax::Feature::Qs> adds C<qs> and C<qqs> that removes all leading whitespace from all lines in a string:
+
+    # these three packages are equivalent:
+    package Example::Nudge {
+
+        use String::Nudge;
+        use syntax 'qs';
+
+        sub out {
+            print nudge qs{
+                This is
+                a multi line
+
+                string.
+            };
+        }
+    }
+    package Example::Q {
+
+        sub out {
+            print q{
+        This is
+        a multi line
+
+        string.
+    };
+        }
+    }
+    package Example::HereDoc {
+
+        sub out {
+
+            (my $text = <<"        END") =~ s{^ {8}}{}gm;
+                This is
+                a multi line
+
+                string.
+            END
+
+            print $text;
+        }
+    }
+
 =head1 SEE ALSO
 
 =over 4
 
-=item L<Indent::String>
+=item *
 
-=item L<String::Indent>
+L<Indent::String>
 
-=item L<qi|Syntax::Feature::Qi>
+=item *
+
+L<String::Indent>
+
+=item *
+
+L<qi|Syntax::Feature::Qi>
+
+=item *
+
+L<qi|Syntax::Feature::Qs>
 
 =back
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-String-Nudge>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/String-Nudge>
+
 =head1 AUTHOR
 
-Erik Carlsson E<lt>info@code301.comE<gt>
+Erik Carlsson <info@code301.com>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2014 - Erik Carlsson
+This software is copyright (c) 2015 by Erik Carlsson.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
